@@ -55,7 +55,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import com.openexchange.database.AbstractCreateTableImpl;
-import com.openexchange.database.DatabaseService;
+import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.Attributes;
 import com.openexchange.groupware.update.PerformParameters;
@@ -63,7 +63,6 @@ import com.openexchange.groupware.update.TaskAttributes;
 import com.openexchange.groupware.update.UpdateExceptionCodes;
 import com.openexchange.groupware.update.UpdateTaskV2;
 import com.openexchange.messaging.generic.services.MessagingGenericServiceRegistry;
-import com.openexchange.tools.sql.DBUtils;
 
 /**
  * {@link MessagingGenericCreateTableTask}
@@ -86,9 +85,9 @@ public final class MessagingGenericCreateTableTask extends AbstractCreateTableIm
         " serviceId VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
         " account INT4 unsigned NOT NULL," +
         " confId INT4 unsigned NOT NULL," +
-        " displayName VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL," +
+        " displayName VARCHAR(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL," +
         " PRIMARY KEY (cid, user, serviceId, account)" +
-        ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
+        ") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci";
     }
 
     @Override
@@ -108,8 +107,7 @@ public final class MessagingGenericCreateTableTask extends AbstractCreateTableIm
 
     @Override
     public void perform(final PerformParameters params) throws com.openexchange.exception.OXException {
-        final int contextId = params.getContextId();
-        createTable("messagingAccount", getMessagingAccountTable(), contextId);
+        createTable("messagingAccount", getMessagingAccountTable(), params.getConnectionProvider().getConnection());
         final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(MessagingGenericCreateTableTask.class);
         logger.info("UpdateTask ''{}'' successfully performed!", MessagingGenericCreateTableTask.class.getSimpleName());
     }
@@ -124,40 +122,31 @@ public final class MessagingGenericCreateTableTask extends AbstractCreateTableIm
         return new String[] { "messagingAccount" };
     }
 
-    private void createTable(final String tablename, final String sqlCreate, final int contextId) throws OXException {
-        final DatabaseService ds = getService(DatabaseService.class);
-        final Connection writeCon;
-        try {
-            writeCon = ds.getWritable(contextId);
-        } catch (final OXException e) {
-            throw e;
-        }
+    private void createTable(String tablename, String sqlCreate, Connection connection) throws OXException {
         PreparedStatement stmt = null;
         try {
-            if (tableExists(writeCon, tablename)) {
+            if (tableExists(connection, tablename)) {
                 return;
             }
-            stmt = writeCon.prepareStatement(sqlCreate);
+
+            stmt = connection.prepareStatement(sqlCreate);
             stmt.executeUpdate();
         } catch (final SQLException e) {
             throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
-            DBUtils.closeSQLStuff(stmt);
-            ds.backWritable(contextId, writeCon);
+            Databases.closeSQLStuff(stmt);
         }
     }
 
     private boolean tableExists(final Connection con, final String table) throws SQLException {
         final DatabaseMetaData metaData = con.getMetaData();
         ResultSet rs = null;
-        boolean retval = false;
         try {
             rs = metaData.getTables(null, null, table, new String[] { "TABLE" });
-            retval = (rs.next() && rs.getString("TABLE_NAME").equals(table));
+            return (rs.next() && rs.getString("TABLE_NAME").equals(table));
         } finally {
-            DBUtils.closeSQLStuff(rs);
+            Databases.closeSQLStuff(rs);
         }
-        return retval;
     }
 
     private <S> S getService(final Class<? extends S> clazz) throws OXException {
